@@ -32,6 +32,8 @@ config_TIMEOUT = 20
 # bufOpenSession['wlan0_keyread'] = False
 # bufOpenSession['wlan0_record'] = False
 # bufOpenSession['wlan0_period'] = 
+# bufOpenSession['wlan0_rx'] = rx эти значения запоминаются, для отслеживания изменения трафика на текущем шаге и предыдущем
+# bufOpenSession['wlan0_tx'] = tx 
 bufOpenSession = {}
 
 
@@ -59,6 +61,10 @@ def getSupportedIface():
 			else:
 				bufOpenSession[ iface + "_keyread" ] = False
 			bufOpenSession[ iface + "_record" ] = my_db.isAutoRecEnable( dataIface['type'] )
+
+			bufOpenSession[ iface+"_rx" ] = 0
+			bufOpenSession[ iface+"_tx" ] = 0
+
 			readTrafOnIface( iface )
 
 #	while i < countIface:
@@ -284,6 +290,18 @@ def readTrafOnIface(iface):
 	except KeyError:
 		keyRecordSession = False
 	
+	rx_prev = 0
+	tx_prev = 0
+	try:
+		rx_prev = bufOpenSession[ iface+"_rx" ]
+	except KeyError:
+		bufOpenSession[ iface+"_rx" ] = 0
+	
+	try:
+		tx_prev = bufOpenSession[ iface+"_tx" ]
+	except KeyError:
+		bufOpenSession[ iface+"_tx" ] = 0
+	
 	#print "readTrafOnIface(%s): bufOpenSession[%s_keyread]=%s bufOpenSession[%s_record]=%s bufOpenSession[%s]=%s"%(iface,iface,keyReadSession,iface,keyRecordSession,iface, timeStartSession)
 	#сессия не стартовала (timeStartSession = None) но есть разрешение на старт keyReadSession = True => стартуем новую сессию
 	if keyReadSession and keyRecordSession and (timeStartSession == None):
@@ -303,8 +321,13 @@ def readTrafOnIface(iface):
 	str_timeSampleTraff = time.strftime( "%Y-%m-%d %H:%M:%S" )
 	mytraff = gettraff.GetTraff( iface )
 	rx, tx, ok = mytraff.getCurrBytes()
-	print "%s: iface=%s  rx=%s  tx=%s"%( str_timeSampleTraff, iface, rx, tx )
-	my_db.writeTraff(rx, tx, type, str_timeSampleTraff)
+
+	if ( rx != rx_prev ) or ( tx != tx_prev ):
+		print "%s: iface=%s  rx=%s  tx=%s"%( str_timeSampleTraff, iface, rx, tx )
+		my_db.writeTraff(rx, tx, type, str_timeSampleTraff)
+
+	bufOpenSession[ iface+"_rx" ] = rx
+	bufOpenSession[ iface+"_tx" ] = tx
 	
 	#"заводим" таймер снова
 	gobject.timeout_add_seconds(config_TIMEOUT, readTrafOnIface, iface)
