@@ -10,10 +10,13 @@ from QNMDBusClient import QNMDBusClient
 QtCore.Signal = QtCore.pyqtSignal
 QtCore.Slot = QtCore.pyqtSlot
 
-from StatistData import pixmapIface_str
+from StatistData import pixmapIface_str, checkOrientation
 from MyItemDelegate import MyItemDelegate
 
 from os import listdir
+from socket import socket, SOCK_DGRAM, AF_INET, inet_ntoa
+from fcntl import ioctl
+from struct import pack
 
 class DialogOptionsIfaceExt(Ui_DialogOptionsIface, QtGui.QWidget):
 	stateRecordChange = QtCore.Signal()
@@ -22,6 +25,11 @@ class DialogOptionsIfaceExt(Ui_DialogOptionsIface, QtGui.QWidget):
 		self.dlg = dlg
 		self.setupUi(dlg)
 		
+		try:
+			self.setAttribute( QtCore.Qt.WA_Maemo5AutoOrientation, True )
+		except Exception, e:
+			pass
+		
 		self.iface_name_clicked_item = ""
 		self.iface_type_clicked_item = ""
 		self.flDeleteIfaceEnable = True
@@ -49,6 +57,9 @@ class DialogOptionsIfaceExt(Ui_DialogOptionsIface, QtGui.QWidget):
 		self.initListIfaces()
 
 		self.getIfconfig()
+		
+		QtCore.QObject.connect( QtGui.QApplication.desktop(), QtCore.SIGNAL("resized(int)"), self.orientationChanged )
+		self.orientationChanged()
 
 
 	def initListIfaces(self):
@@ -246,6 +257,7 @@ class DialogOptionsIfaceExt(Ui_DialogOptionsIface, QtGui.QWidget):
 	def getIfconfig( self ):
 		self.tEIfaceInfo.clear()
 
+		txt_ip = QtGui.QApplication.translate("DialogOptionsIfaceExt", "IP address", None, QtGui.QApplication.UnicodeUTF8)
 		txt_mac = QtGui.QApplication.translate("DialogOptionsIfaceExt", "MAC address", None, QtGui.QApplication.UnicodeUTF8)
 		rx_b_p = QtGui.QApplication.translate("DialogOptionsIfaceExt", "RX bytes/RX packets", None, QtGui.QApplication.UnicodeUTF8)
 		tx_b_p = QtGui.QApplication.translate("DialogOptionsIfaceExt", "TX bytes/TX packets", None, QtGui.QApplication.UnicodeUTF8)
@@ -270,7 +282,11 @@ class DialogOptionsIfaceExt(Ui_DialogOptionsIface, QtGui.QWidget):
 			txb = self.fileData( tx_b )
 			txp = self.fileData( tx_p )
 
+			ip = self.getip_iface(nif)
+
 			s += "<dt><b>%s:</b></dt>"%(nif)
+			if ip != "":
+				s += "<dd><b>%s:</b><br/>%s</dd>"%(txt_ip,ip)
 			s += "<dd><b>%s:</b><br/>%s</dd>"%(txt_mac,mac)
 			s += "<dd><b>%s:</b><br>%s / %s</dd>"%(rx_b_p, rxb, rxp)
 			s += "<dd><b>%s:</b><br>%s / %s</dd>"%(tx_b_p, txb, txp)
@@ -287,3 +303,36 @@ class DialogOptionsIfaceExt(Ui_DialogOptionsIface, QtGui.QWidget):
 			d = qf.readLine()
 			qf.close()
 		return d
+	
+	
+	def orientationChanged( self ):
+			
+		self.gridLayout.removeWidget( self.tEIfaceInfo )
+		self.gridLayout.removeWidget( self.lWIface )
+		self.gridLayout.removeItem( self.horizontalLayoutButtons )
+
+		o = checkOrientation()
+		if o == "L":
+			# landscape
+			self.resize(800, 360)
+			self.gridLayout.addWidget( self.tEIfaceInfo, 0, 0, 2, 1 )
+			self.gridLayout.addWidget( self.lWIface, 0, 1, 1, 1 )
+
+			self.gridLayout.addItem( self.horizontalLayoutButtons, 1, 1, 1, 1 )
+		else:
+			#portait
+			self.resize(440, 600)
+			self.gridLayout.addWidget( self.tEIfaceInfo, 0, 0 )
+			self.gridLayout.addWidget( self.lWIface, 1, 0 )
+
+			self.gridLayout.addItem( self.horizontalLayoutButtons, 2, 0 )
+
+
+	def getip_iface( self, ifname ):
+		ret = ""
+		try:
+			s = socket(AF_INET, SOCK_DGRAM)
+			ret = inet_ntoa( ioctl ( s.fileno(), 0x8915, pack('256s', ifname[:15]) )[20:24])
+		except Exception, e:
+			pass
+		return ret
