@@ -315,18 +315,18 @@ class QNMSettings(QtCore.QSettings):
 
 	#----------------------------------#
 	def setTypeGraphStatSession( self ):
-		self.beginGroup( self.groupMonitorOpt )
-		self.setValue(self.key_graphType,"0")
+		self.beginGroup( self.groupSessionOpt )
+		self.setValue(self.key_graphType_s,"0")
 		self.endGroup()
 	
 	def setTypeGraphTimeSession( self ):
-		self.beginGroup( self.groupMonitorOpt )
-		self.setValue(self.key_graphType, "1")
+		self.beginGroup( self.groupSessionOpt )
+		self.setValue(self.key_graphType_s, "1")
 		self.endGroup()
 
 	def isTypeGrapStatSession(self):
-		self.beginGroup( self.groupMonitorOpt )
-		val = self.value( self.key_graphType, "0" )
+		self.beginGroup( self.groupSessionOpt )
+		val = self.value( self.key_graphType_s, "0" )
 		self.endGroup()
 		if val == "0":
 			return True
@@ -334,8 +334,8 @@ class QNMSettings(QtCore.QSettings):
 			return False
 	
 	def isTypeGrapTimeSession(self):
-		self.beginGroup( self.groupMonitorOpt )
-		val = self.value( self.key_graphType, "1" )
+		self.beginGroup( self.groupSessionOpt )
+		val = self.value( self.key_graphType_s, "1" )
 		self.endGroup()
 		if val == "1":
 			return True
@@ -343,8 +343,8 @@ class QNMSettings(QtCore.QSettings):
 			return False
 	
 	def typeGraphSession(self):
-		self.beginGroup( self.groupMonitorOpt )
-		val = self.value( self.key_graphType, "0" )
+		self.beginGroup( self.groupSessionOpt )
+		val = self.value( self.key_graphType_s, "0" )
 		self.endGroup()
 		if val == "1":
 			return 1
