@@ -91,3 +91,12 @@ def pixmapIface_str( name_iface ):
 		item_pic = ":/pic48/pictures/netdevice.png"
 	
 	return item_pic
+
+
+def checkOrientation():
+	screenGeometry = QtGui.QApplication.desktop().screenGeometry()
+	if screenGeometry.width() > screenGeometry.height():
+		return "L"
+	else:
+		return "P"
+
