@@ -8,7 +8,7 @@ import ViewCurrentSession
 import DialogRefreshInterval
 import DialogNetworkIface
 import DialogRecordDataExt
-import MonitorOptions
+import MonitorOptionsExt
 import StatistData
 
 from collections import deque
@@ -45,9 +45,17 @@ class ViewCurrentSessionExt( QtGui.QMainWindow ):
 
 		self.qset = qset
 
+		#геомертические параметры отображаемого графика
+		self.lengthX = 770
+		self.lengthY = 280
+		self.shiftX = 0
+		self.shiftY = 10
+		
+		#ширина линии графика (пиксель)
+		self.pxLenGraph = 5
+
 		self.frm = ViewCurrentSession.Ui_ViewCurrentSession()
 		self.frm.setupUi( self )
-		self.actionForm()
 
 		listSupportIface = self.db.optGetSupportIface()
 		if len(listSupportIface) != 0:
@@ -87,12 +95,6 @@ class ViewCurrentSessionExt( QtGui.QMainWindow ):
 		self.viewPointOnGraphRX = deque([])
 		self.viewPointOnGraphTX = deque([])
 
-		#геомертические параметры отображаемого графика
-		self.lengthX = 770
-		self.lengthY = 280
-		self.shiftX = 0
-		self.shiftY = 10
-		
 		#вспомогательные переменные
 		#длина графика по оси Y
 		self.Ly = self.lengthY-self.shiftY
@@ -146,9 +148,6 @@ class ViewCurrentSessionExt( QtGui.QMainWindow ):
 
 		# *** * *** #
 
-		#ширина линии графика (пиксель)
-		self.pxLenGraph = 5
-
 		self.noti = MyNotify()
 
 		self.dbusWaitDisplayOff()
@@ -157,6 +156,8 @@ class ViewCurrentSessionExt( QtGui.QMainWindow ):
 		self.session_bus = dbus.SessionBus( )
 		self.session_bus.add_signal_receiver( self.dbusSignalReceiver_recStarted, dbus_interface=None, signal_name="recStarted", bus_name="com.qnetman.Daemon", path="/QNetManDBus")
 		self.session_bus.add_signal_receiver( self.dbusSignalReceiver_recStoped, dbus_interface=None, signal_name="recStoped", bus_name="com.qnetman.Daemon", path="/QNetManDBus")
+		
+		self.actionForm()
 	
 
 	#обработчкик dbus - сигналов запуска/остановки записи на сетевых интерфейсах
@@ -249,16 +250,19 @@ class ViewCurrentSessionExt( QtGui.QMainWindow ):
 		#print >> sys.stderr, "getTraffData ok"
 
 		# проталкиваем очередное полученное значение в очередь
-		if( (self.X+dx) > self.lengthX ):
+		# при этом "лишнюю заднюю часть" из деки отбрасываем
+		#@#if( (self.X+dx) > self.lengthX ): #@#-коммент старого, для отладки поворота графика на экране
+		while( (self.X+dx) > self.lengthX ):
 			try:
 				self.viewPointOnGraphRX.popleft()
+				self.X = self.X - self.pxLenGraph
 			except:
 				pass
 			try:
 				self.viewPointOnGraphTX.popleft()
 			except:
 				pass
-			self.X = self.lengthX
+			#@#self.X = self.lengthX
 		self.viewPointOnGraphRX.append( rx )
 		self.viewPointOnGraphTX.append( tx )
 		#print >> sys.stderr, "popleft ok"
@@ -328,7 +332,6 @@ class ViewCurrentSessionExt( QtGui.QMainWindow ):
 				j += 1
 
 		self.X = self.X + self.pxLenGraph
-		#print >> sys.stderr, "draw gr ok"
 
 		#отрисовка сетки и системы координат
 		self.drawSystemCoord()
@@ -401,6 +404,7 @@ class ViewCurrentSessionExt( QtGui.QMainWindow ):
 
 		return (rx, tx, okread)
 
+
 	def actionForm(self):
 		self.frm.pBrec.clicked.connect( self.dlgRecordData )
 		self.frm.pbRecordStatus.clicked.connect( self.notifyRecNow )
@@ -411,9 +415,8 @@ class ViewCurrentSessionExt( QtGui.QMainWindow ):
 		# кнопка вызова диалога "Настройки монитора" и вся соответствующая ей хрень
 		self.frm.pBopt.clicked.connect( self.dialogMonitorOptions )
 
-		self.dlgMO = QtGui.QDialog()
-		self.ui_dlgMO = MonitorOptions.Ui_DialogMonitorOptions( )
-		self.ui_dlgMO.setupUi( self.dlgMO )
+		self.dlgMO = QtGui.QDialog( self )
+		self.ui_dlgMO = MonitorOptionsExt.MonitorOptionsExt( self.dlgMO )
 
 		self.ui_dlgMO.bGrGraphType.buttonPressed.connect( self.changeGrT )
 		##XXX##
@@ -422,15 +425,10 @@ class ViewCurrentSessionExt( QtGui.QMainWindow ):
 		self.ui_dlgMO.pbTraffTX.toggled.connect( self.changeShowTX )
 		self.ui_dlgMO.sbTimestamp.valueChanged.connect( self.changeTimestamp )
 
-		pic = QtGui.QPixmap(":/pic128/pictures/2dowarrow_128.png")
-		self.frm.lblInput.setPixmap( pic.scaled(32,32) )
-		self.frm.lblIndexRX.setPixmap( pic.scaled(16,16) )
-		self.frm.lblInput.setText("")
-			
-		pic = QtGui.QPixmap(":/pic128/pictures/2uparrow_128.png")
-		self.frm.lblOutput.setPixmap( pic.scaled(32,32) )
-		self.frm.lblIndexTX.setPixmap( pic.scaled(16,16) )
-		self.frm.lblOutput.setText("")
+		self.frm.widgetLegend.setParent(self.frm.graphicsView)
+		self.frm.widgetRecordStatus.setParent(self.frm.graphicsView)
+		QtCore.QObject.connect( QtGui.QApplication.desktop(), QtCore.SIGNAL("resized(int)"), self.orientationChanged )
+		self.orientationChanged()
 
 
 	def changeShowRX(self, state):
@@ -488,7 +486,7 @@ class ViewCurrentSessionExt( QtGui.QMainWindow ):
 	
 	#-----------------#
 	def dialogRefreshInterval(self):
-		self.dlg = QtGui.QDialog( )
+		self.dlg = QtGui.QDialog( self )
 		self.ui_dlg = DialogRefreshInterval.Ui_Dialog()
 		self.ui_dlg.setupUi( self.dlg )
 		#self.ui_dlg.lblValue.setText( "%s sec"%self.timeout )
@@ -589,7 +587,7 @@ class ViewCurrentSessionExt( QtGui.QMainWindow ):
 
 	#-----------------#
 	def dialogIfaceSelect(self):
-		self.dlgIface = QtGui.QDialog()
+		self.dlgIface = QtGui.QDialog( self )
 		self.ui_dlgIface = DialogNetworkIface.Ui_dlgNetworkSelect()
 		self.ui_dlgIface.setupUi( self.dlgIface )
 		
@@ -644,7 +642,7 @@ class ViewCurrentSessionExt( QtGui.QMainWindow ):
 
 	#-----------------#
 	def dlgRecordData(self):
-		self.dlgRec = QtGui.QDialog()
+		self.dlgRec = QtGui.QDialog( self )
 		self.ui_dlgRec = DialogRecordDataExt.DialogRecordManagerExt( self.dlgRec, self.db, self.mydbus )
 		#XXX# вроде уже не нужно, т.к. изменение записи определяется приемом dbus сигналов
 		#self.ui_dlgRec.stateRecordChange.connect( self.stateRecordChangeHere )
@@ -685,4 +683,63 @@ class ViewCurrentSessionExt( QtGui.QMainWindow ):
 		txt = QtGui.QApplication.translate("ViewCurrentSessionExt", "Recording...", None, QtGui.QApplication.UnicodeUTF8)
 		self.noti.notify( "%s"%(txt) )
 
+	#===================================#
+
+	def orientationChanged( self ):
+			
+		self.frm.gridLayout.removeWidget( self.frm.graphicsView )
+		self.frm.gridLayout.removeItem( self.frm.hL_buttons )
+		self.frm.gridLayout.removeItem( self.frm.hL_traffRX )
+		self.frm.gridLayout.removeItem( self.frm.hL_traffTX )
+		self.frm.gridLayout.removeItem( self.frm.hL_speedRX )
+		self.frm.gridLayout.removeItem( self.frm.hL_speedTX )
+
+		o = StatistData.checkOrientation()
+		if o == "L":
+			# landscape
+			self.lengthX = 770
+			self.lengthY = 280
+
+			self.frm.graphicsView.setMinimumSize(QtCore.QSize(780, 300))
+
+			self.frm.gridLayout.addWidget( self.frm.graphicsView, 0, 0, 1, 3 )
+			self.frm.gridLayout.addItem( self.frm.hL_traffRX, 1, 0, 1, 1 )
+			self.frm.gridLayout.addItem( self.frm.hL_traffTX, 2, 0, 1, 1 )
+			self.frm.gridLayout.addItem( self.frm.hL_speedRX, 1, 1, 1, 1 )
+			self.frm.gridLayout.addItem( self.frm.hL_speedTX, 2, 1, 1, 1 )
+			
+			self.frm.gridLayout.addItem( self.frm.hL_buttons, 1, 2, 2, 1 )
+
+			#self.frm.hL_tools.setGeometry( QtCore.QRect(1, 1, self.frm.hL_tools.geometry().width(), self.frm.hL_tools.geometry().height() ))
+			self.frm.widgetRecordStatus.move( 530, 18 ) #w=75
+			self.frm.widgetLegend.move( 610, 18 )
+		else:
+			#portait
+			self.lengthX = 410
+			self.lengthY = 530
+
+			self.frm.graphicsView.setMinimumSize(QtCore.QSize(420, 550))
+
+			self.frm.gridLayout.addWidget( self.frm.graphicsView, 0, 0, 1, 2 )
+			
+			self.frm.gridLayout.addItem( self.frm.hL_traffRX, 1, 0, 1, 1 )
+			self.frm.gridLayout.addItem( self.frm.hL_speedRX, 1, 1, 1, 1 )
+
+			self.frm.gridLayout.addItem( self.frm.hL_traffTX, 2, 0, 1, 1 )
+			self.frm.gridLayout.addItem( self.frm.hL_speedTX, 2, 1, 1, 1 )
+			
+			self.frm.gridLayout.addItem( self.frm.hL_buttons, 3, 0, 2, 2 )
+		
+			#self.frm.hL_tools.setGeometry( QtCore.QRect(1, 1, self.frm.hL_tools.geometry().width(), self.frm.hL_tools.geometry().height() ))
+			self.frm.widgetRecordStatus.move( 200, 18 )
+			self.frm.widgetLegend.move( 280, 18 )
+		#вспомогательные переменные
+		#длина графика по оси Y
+		self.Ly = self.lengthY-self.shiftY
+		#длина графика по оси X
+		self.Lx = self.lengthX-self.shiftX
+
+		self.frm.graphicsView.setSceneRect(0, 0, self.lengthX, self.lengthY)
+		self.drawGraph() #XXX# остановить таймер, вызвать функцию, запустить таймер (???)
+
 
