@@ -28,7 +28,7 @@ class WinAboutExt( QtGui.QMainWindow ):
 		self.createSlidingStackedWidget()
 
 		#XXX# Версия программы #XXX#
-		self.ui.lblVersionVal.setText("0.9.0")
+		self.ui.lblVersionVal.setText("0.9.2")
 
 		self.actionForm()
 
@@ -147,7 +147,7 @@ class WinAboutExt( QtGui.QMainWindow ):
 		txt1 = QtGui.QApplication.translate("WinAboutExt", "Thanks:", None, QtGui.QApplication.UnicodeUTF8)
 		txt2 = QtGui.QApplication.translate("WinAboutExt", "Vladimir Sinichkin - for translation", None, QtGui.QApplication.UnicodeUTF8)
 		txt3 = QtGui.QApplication.translate("WinAboutExt", "Used icon set \"Crystal-clear\" by Everaldo Coelho", None, QtGui.QApplication.UnicodeUTF8)
-		txt4 = QtGui.QApplication.translate("WinAboutExt", "Krisztian Olah - for testing and good ideas", None, QtGui.QApplication.UnicodeUTF8)
+		txt4 = QtGui.QApplication.translate("WinAboutExt", "Krisztian Olah - for testing and good ideas (Hungarian translation)", None, QtGui.QApplication.UnicodeUTF8)
 		str  = "<html>"
 		str += "<div style='font-size: 14pt;'>"
 		str += "<p>%s</p>"%txt1
