@@ -193,18 +193,16 @@ class WinNetStatExt( QtGui.QMainWindow ):
 		self.timeoutAutoRefresh = self.qset.refreshInterval_ns()
 		self.timerAutoRefresh = QtCore.QTimer()
 		QtCore.QObject.connect( self.timerAutoRefresh, QtCore.SIGNAL("timeout()"), self.doAutoRefreshData )
-
-#		self.colorESTABLISHED = QtGui.QColor("#34c924")
-#		self.colorLISTEN = QtGui.QColor("#0000ff")
-#		self.colorCLOSE_C = QtGui.QColor("#ff0000")
-#		self.colorCLOSE_S = QtGui.QColor("#808080")
-#		self.colorSYN_S = QtGui.QColor("#ffff00")
-#		self.colorSYN_C = QtGui.QColor("#ffa500")
 		
 		plugin = MyItemDelegate( self, 0 )
 		self.listConn.setItemDelegate( plugin )
 
 		self.ui_procInfo.lblDescrText.setFontPointSize(12)
+		
+		QtCore.QObject.connect( QtGui.QApplication.desktop(), QtCore.SIGNAL("resized(int)"), self.orientationChanged )
+		self.orientationChanged()
+
+
 
 	#функция для первого вызова при создании объекта
 	#после того, как вызвали show()
@@ -570,7 +568,7 @@ class WinNetStatExt( QtGui.QMainWindow ):
 
 	#------------------------#
 	def dialogRefreshInterval(self):
-		self.dlg = QtGui.QDialog( )
+		self.dlg = QtGui.QDialog( self )
 		self.ui_dlg = Ui_DialogRefreshNetstat()
 		self.ui_dlg.setupUi( self.dlg )
 		self.ui_dlg.lWinterval.itemClicked.connect( self.setRefreshInterval )
@@ -586,3 +584,40 @@ class WinNetStatExt( QtGui.QMainWindow ):
 			self.timerAutoRefresh.stop()
 			self.timerAutoRefresh.start( (self.timeoutAutoRefresh*1000) )
 		self.qset.setRefreshInterval_ns( self.timeoutAutoRefresh )
+
+
+	#============================================================================#
+
+	def orientationChanged( self ):
+		screenGeometry = QtGui.QApplication.desktop().screenGeometry()
+		
+		self.ui.gridLayout.removeItem( self.ui.hL_update )
+		self.ui.gridLayout.removeWidget( self.ui.pb_resolve )
+		self.ui.gridLayout.removeItem( self.ui.hL_proto )
+		self.ui.gridLayout.removeWidget( self.ui.pb_infoProc )
+		self.ui.gridLayout.removeWidget( self.ui.ww )
+
+		if screenGeometry.width() > screenGeometry.height():
+			# landscape
+			#self.parentDialog.setMaximumSize(800, 270)
+			#self.parentDialog.setMinimumSize(800, 270)
+			self.w_refresh.setGeometry(QtCore.QRect(670, 10, 130, 50))
+
+			self.ui.gridLayout.addWidget( self.ui.ww, 0, 0, 1, 4 )
+			self.ui.gridLayout.addItem( self.ui.hL_update, 1, 0, 1, 1 )
+			self.ui.gridLayout.addWidget( self.ui.pb_resolve, 1, 1, 1, 1 )
+			self.ui.gridLayout.addItem( self.ui.hL_proto, 1, 2, 1, 1 )
+			self.ui.gridLayout.addWidget( self.ui.pb_infoProc, 1, 3, 1, 1 )
+		else:
+			#portait
+			#self.parentDialog.setMaximumSize(440, 410)
+			#self.parentDialog.setMinimumSize(440, 410)
+			self.w_refresh.setGeometry(QtCore.QRect(330, 10, 130, 50))
+
+			self.ui.gridLayout.addWidget( self.ui.ww, 0, 0, 1, 2 )
+			self.ui.gridLayout.addItem( self.ui.hL_update, 1, 0, 1, 1 )
+			self.ui.gridLayout.addItem( self.ui.hL_proto, 1, 1, 1, 1 )
+			self.ui.gridLayout.addWidget( self.ui.pb_resolve, 2, 0, 1, 1 )
+			self.ui.gridLayout.addWidget( self.ui.pb_infoProc, 2, 1, 1, 1 )
+
+
