@@ -40,6 +40,9 @@ if __name__ == "__main__":
 	elif L == "ru":
 		trans.load( myconfig.i18n_rus )
 		app.installTranslator( trans )
+	elif L == "hu":
+		trans.load( myconfig.i18n_hun )
+		app.installTranslator( trans )
 	
 	#ui = MainWindowExt.MainWindowExt( splash )
 	ui = MainWindowExt.MainWindowExt( qset )
